@@ -1,10 +1,10 @@
 package Math::Random::Discrete;
-{
-  $Math::Random::Discrete::VERSION = '1.01';
-}
+$Math::Random::Discrete::VERSION = '1.02';
 use strict;
 use warnings;
 
+use Carp qw(croak);
+
 # ABSTRACT: Discrete random variables with general distributions
 
 # This is an implementation of Walker's alias method.
@@ -12,6 +12,11 @@ use warnings;
 sub new {
     my ($class, $_weights, $values) = @_;
 
+    croak("No weights specified")
+        if !defined($_weights) || !@$_weights;
+    croak("Number of values must equal number of weights")
+        if defined($values) && @$values != @$_weights;
+
     my @weights = @$_weights;
 
     # compute average weight
@@ -99,7 +104,7 @@ Math::Random::Discrete - Discrete random variables with general distributions
 
 =head1 VERSION
 
-version 1.01
+version 1.02
 
 =head1 SYNOPSIS
 
@@ -144,7 +149,7 @@ Nick Wellnhofer <wellnhofer@aevum.de>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Nick Wellnhofer.
+This software is copyright (c) 2015 by Nick Wellnhofer.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
